@@ -1,7 +1,11 @@
-/* p80211types.h: Macros, constants, types, and funcs for p80211 data types
+/* src/include/wlan/p80211types.h
+*
+* Macros, constants, types, and funcs for p80211 data types
+*
+* Copyright (C) 1999 AbsoluteValue Systems, Inc.  All Rights Reserved.
 * --------------------------------------------------------------------
 *
-* Linux WLAN 
+* linux-wlan
 *
 *   The contents of this file are subject to the Mozilla Public
 *   License Version 1.1 (the "License"); you may not use this file
@@ -13,10 +17,6 @@
 *   implied. See the License for the specific language governing
 *   rights and limitations under the License.
 *
-*   The initial developer of the original code is Mark S. Mathews
-*   <mark@absoval.com>.  Portions created by Mark S. Mathews are 
-*   Copyright (C) 1999 AbsoluteValue Software, Inc.  All Rights Reserved.
-*
 *   Alternatively, the contents of this file may be used under the
 *   terms of the GNU Public License version 2 (the "GPL"), in which
 *   case the provisions of the GPL are applicable instead of the
@@ -30,9 +30,12 @@
 *
 * --------------------------------------------------------------------
 *
-* The initial author may be reached as mark@absoval.com, or 
-* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
-* Maitland, FL, 32794-1149
+* Inquiries regarding the linux-wlan Open Source project can be
+* made directly to:
+*
+* AbsoluteValue Systems Inc.
+* info@linux-wlan.com
+* http://www.linux-wlan.com
 *
 * --------------------------------------------------------------------
 *
@@ -94,18 +97,18 @@
 #define P80211_MIB_CAT_DOT11MAC		2
 #define P80211_MIB_CAT_DOT11PHY		3
 
-#define P80211SEC_DOT11SMT	P80211_MIB_CAT_DOT11SMT
-#define P80211SEC_DOT11MAC	P80211_MIB_CAT_DOT11MAC
-#define P80211SEC_DOT11PHY	P80211_MIB_CAT_DOT11PHY
+#define P80211SEC_DOT11SMT		P80211_MIB_CAT_DOT11SMT
+#define P80211SEC_DOT11MAC		P80211_MIB_CAT_DOT11MAC
+#define P80211SEC_DOT11PHY		P80211_MIB_CAT_DOT11PHY
 
 /* Message Category List */
 #define P80211_MSG_CAT_DOT11REQ		1
 #define P80211_MSG_CAT_DOT11IND		2
 /* #define P80211_MSG_CAT_DOT11CFM		3 (doesn't exist at this time) */
 
-#define P80211SEC_DOT11REQ	P80211_MSG_CAT_DOT11REQ
-#define P80211SEC_DOT11IND	P80211_MSG_CAT_DOT11IND
-/* #define P80211SEC_DOT11CFM	P80211_MSG_CAT_DOT11CFM  (doesn't exist at this time */
+#define P80211SEC_DOT11REQ		P80211_MSG_CAT_DOT11REQ
+#define P80211SEC_DOT11IND		P80211_MSG_CAT_DOT11IND
+/* #define P80211SEC_DOT11CFM		P80211_MSG_CAT_DOT11CFM  (doesn't exist at this time */
 
 
 
@@ -230,9 +233,9 @@
 
 /* MSM: Do these belong in p80211meta.h? I'm not sure. */
 
-#define ISREQUIRED	(0x80000000UL)
-#define ISREQUEST	(0x40000000UL)
-#define ISCONFIRM	(0x20000000UL)
+#define ISREQUIRED		(0x80000000UL)
+#define ISREQUEST		(0x40000000UL)
+#define ISCONFIRM		(0x20000000UL)
 
 
 /*================================================================*/
@@ -511,8 +514,15 @@ typedef struct  p80211item_unk1024
 } p80211item_unk1024_t;
 __WLAN_PRAGMA_PACK1__
 
-
-
+/* message data item for UNK 4096, namely p2 download chunks */
+typedef struct  p80211item_unk4096
+{
+	UINT32		did				__WLAN_ATTRIB_PACK__;
+	UINT16		status				__WLAN_ATTRIB_PACK__;
+	UINT16		len				__WLAN_ATTRIB_PACK__;
+	UINT8		data[4096]			__WLAN_ATTRIB_PACK__;
+} p80211item_unk4096_t;
+__WLAN_PRAGMA_PACK1__
 
 struct catlistitem;
 
