@@ -1,7 +1,11 @@
-/* wlan_compat.h: Types and macros to aid in portability
+/* src/include/wlan/wlan_compat.h
+*
+* Types and macros to aid in portability
+*
+* Copyright (C) 1999 AbsoluteValue Systems, Inc.  All Rights Reserved.
 * --------------------------------------------------------------------
 *
-* Linux WLAN 
+* linux-wlan
 *
 *   The contents of this file are subject to the Mozilla Public
 *   License Version 1.1 (the "License"); you may not use this file
@@ -13,10 +17,6 @@
 *   implied. See the License for the specific language governing
 *   rights and limitations under the License.
 *
-*   The initial developer of the original code is Mark S. Mathews
-*   <mark@absoval.com>.  Portions created by Mark S. Mathews are 
-*   Copyright (C) 1999 AbsoluteValue Software, Inc.  All Rights Reserved.
-*
 *   Alternatively, the contents of this file may be used under the
 *   terms of the GNU Public License version 2 (the "GPL"), in which
 *   case the provisions of the GPL are applicable instead of the
@@ -30,9 +30,12 @@
 *
 * --------------------------------------------------------------------
 *
-* The initial author may be reached as mark@absoval.com, or 
-* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
-* Maitland, FL, 32794-1149
+* Inquiries regarding the linux-wlan Open Source project can be
+* made directly to:
+*
+* AbsoluteValue Systems Inc.
+* info@linux-wlan.com
+* http://www.linux-wlan.com
 *
 * --------------------------------------------------------------------
 *
@@ -60,7 +63,7 @@
 /* WLAN_CPU_PART */
 	#define WLAN_I386PART			1
 	#define WLAN_MPC860			2
-	#define WLAN_MPC850			3
+	#define WLAN_MPC823			3
 	#define WLAN_I296SA			4
 	#define WLAN_PPCPART			5
 /* WLAN_SYSARCH */
@@ -83,6 +86,14 @@
 	#define WLAN_PCI			3
 	#define WLAN_USB			4
 
+/* LinuxPPC users! uncomment the following line to build for LinuxPPC */
+/*   a header file change has created a small problem that will be fixed */
+/*   in the next release.  For the time being we can't automagically */
+/*   detect LinuxPPC */
+
+/* #define CONFIG_PPC 1 */
+
+
 /* Lets try to figure out what we've got. */
 #if defined(__LINUX_WLAN__) && defined(__KERNEL__)
 	#define WLAN_OS				WLAN_LINUX_KERNEL
@@ -98,8 +109,11 @@
 		#if defined(CONFIG_MBX)
 			#define WLAN_CPU_PART	WLAN_MPC860
 			#define WLAN_SYSARCH	WLAN_MBX
-		#elif defined(CONFIG_RPX)
-			#define WLAN_CPU_PART	WLAN_MPC850
+		#elif defined(CONFIG_RPXLITE)
+			#define WLAN_CPU_PART	WLAN_MPC823
+			#define WLAN_SYSARCH	WLAN_RPX
+		#elif defined(CONFIG_RPXCLASSIC)
+			#define WLAN_CPU_PART	WLAN_MPC860
 			#define WLAN_SYSARCH	WLAN_RPX
 		#else
 			#define WLAN_CPU_PART	WLAN_PPCPART
@@ -270,23 +284,23 @@ typedef signed int      INT;
 #endif
 
 #if (WLAN_OS == WLAN_LINUX_KERNEL)
-	#define WLAN_LOG_ERROR0(s) printk(KERN_ERR s);
-	#define WLAN_LOG_ERROR1(s,n) printk(KERN_ERR s, (n));
-	#define WLAN_LOG_ERROR2(s,n1,n2) printk(KERN_ERR s, (n1), (n2));
-	#define WLAN_LOG_ERROR3(s,n1,n2,n3) printk(KERN_ERR s, (n1), (n2), (n3));
-	#define WLAN_LOG_ERROR4(s,n1,n2,n3,n4) printk(KERN_ERR ": " s, (n1), (n2), (n3), (n4));
+	#define WLAN_LOG_ERROR0(s) printk(KERN_ERR __FUNCTION__ ": " s);
+	#define WLAN_LOG_ERROR1(s,n) printk(KERN_ERR __FUNCTION__ ": " s, (n));
+	#define WLAN_LOG_ERROR2(s,n1,n2) printk(KERN_ERR __FUNCTION__ ": " s, (n1), (n2));
+	#define WLAN_LOG_ERROR3(s,n1,n2,n3) printk(KERN_ERR __FUNCTION__ ": " s, (n1), (n2), (n3));
+	#define WLAN_LOG_ERROR4(s,n1,n2,n3,n4) printk(KERN_ERR __FUNCTION__ ": " s, (n1), (n2), (n3), (n4));
 
-	#define WLAN_LOG_WARNING0(s) printk(KERN_WARNING s);
-	#define WLAN_LOG_WARNING1(s,n) printk(KERN_WARNING s, (n));
-	#define WLAN_LOG_WARNING2(s,n1,n2) printk(KERN_WARNING s, (n1), (n2));
-	#define WLAN_LOG_WARNING3(s,n1,n2,n3) printk(KERN_WARNING s, (n1), (n2), (n3));
-	#define WLAN_LOG_WARNING4(s,n1,n2,n3,n4) printk(KERN_WARNING ": " s, (n1), (n2), (n3), (n4));
+	#define WLAN_LOG_WARNING0(s) printk(KERN_WARNING __FUNCTION__ ": " s);
+	#define WLAN_LOG_WARNING1(s,n) printk(KERN_WARNING __FUNCTION__ ": " s, (n));
+	#define WLAN_LOG_WARNING2(s,n1,n2) printk(KERN_WARNING __FUNCTION__ ": " s, (n1), (n2));
+	#define WLAN_LOG_WARNING3(s,n1,n2,n3) printk(KERN_WARNING __FUNCTION__ ": " s, (n1), (n2), (n3));
+	#define WLAN_LOG_WARNING4(s,n1,n2,n3,n4) printk(KERN_WARNING __FUNCTION__ ": " ": " s, (n1), (n2), (n3), (n4));
 
-	#define WLAN_LOG_NOTICE0(s) printk(KERN_NOTICE s);
-	#define WLAN_LOG_NOTICE1(s,n) printk(KERN_NOTICE s, (n));
-	#define WLAN_LOG_NOTICE2(s,n1,n2) printk(KERN_NOTICE s, (n1), (n2));
-	#define WLAN_LOG_NOTICE3(s,n1,n2,n3) printk(KERN_NOTICE s, (n1), (n2), (n3));
-	#define WLAN_LOG_NOTICE4(s,n1,n2,n3,n4) printk(KERN_NOTICE s, (n1), (n2), (n3), (n4));
+	#define WLAN_LOG_NOTICE0(s) printk(KERN_NOTICE __FUNCTION__ ": " s);
+	#define WLAN_LOG_NOTICE1(s,n) printk(KERN_NOTICE __FUNCTION__ ": " s, (n));
+	#define WLAN_LOG_NOTICE2(s,n1,n2) printk(KERN_NOTICE __FUNCTION__ ": " s, (n1), (n2));
+	#define WLAN_LOG_NOTICE3(s,n1,n2,n3) printk(KERN_NOTICE __FUNCTION__ ": " s, (n1), (n2), (n3));
+	#define WLAN_LOG_NOTICE4(s,n1,n2,n3,n4) printk(KERN_NOTICE __FUNCTION__ ": " s, (n1), (n2), (n3), (n4));
 
 	#define WLAN_LOG_INFO0(s) printk(KERN_INFO s);
 	#define WLAN_LOG_INFO1(s,n) printk(KERN_INFO s, (n));
@@ -340,13 +354,13 @@ typedef signed int      INT;
 	#define WLAN_LOG_ERROR1(s,n) kprintf(KERN_ERR s, (n));
 	#define WLAN_LOG_ERROR2(s,n1,n2) kprintf(KERN_ERR s, (n1), (n2));
 	#define WLAN_LOG_ERROR3(s,n1,n2,n3) kprintf(KERN_ERR s, (n1), (n2), (n3));
-	#define WLAN_LOG_ERROR4(s,n1,n2,n3,n4) kprintf(KERN_ERR ": " s, (n1), (n2), (n3), (n4));
+	#define WLAN_LOG_ERROR4(s,n1,n2,n3,n4) kprintf(KERN_ERR s, (n1), (n2), (n3), (n4));
 
 	#define WLAN_LOG_WARNING0(s) kprintf(KERN_WARNING s);
 	#define WLAN_LOG_WARNING1(s,n) kprintf(KERN_WARNING s, (n));
 	#define WLAN_LOG_WARNING2(s,n1,n2) kprintf(KERN_WARNING s, (n1), (n2));
 	#define WLAN_LOG_WARNING3(s,n1,n2,n3) kprintf(KERN_WARNING s, (n1), (n2), (n3));
-	#define WLAN_LOG_WARNING4(s,n1,n2,n3,n4) kprintf(KERN_WARNING ": " s, (n1), (n2), (n3), (n4));
+	#define WLAN_LOG_WARNING4(s,n1,n2,n3,n4) kprintf(KERN_WARNING s, (n1), (n2), (n3), (n4));
 
 	#define WLAN_LOG_NOTICE0(s) kprintf(KERN_NOTICE s);
 	#define WLAN_LOG_NOTICE1(s,n) kprintf(KERN_NOTICE s, (n));
@@ -541,7 +555,43 @@ typedef signed int      INT;
 		#define ntohs(n) (n)
 	#endif
 #else
-	#error "WLAN_OS not defined or unsupported for definition of ieee2hostXX"
+	#error "WLAN_OS not defined"
+#endif
+
+
+
+#if (WLAN_OS == WLAN_LINUX_KERNEL && WLAN_CPU_FAMILY == WLAN_Ix86)
+	#define wlan_inb(a)			inb((a))
+	#define wlan_inw(a)			inw((a))
+	#define wlan_inw_le16_to_cpu(a)		inw((a))
+	#define wlan_inw_be16_to_cpu(a)		(__be16_to_cpu(inw((a))))
+	#define wlan_inl(a)			inl((a))
+	#define wlan_inl_le32_to_cpu(a)		inl((a))
+	#define wlan_inl_be32_to_cpu(a)		(__be32_to_cpu(inl((a))))
+
+	#define wlan_outb(v,a)			outb((v),(a))
+	#define wlan_outw(v,a)			outw((v),(a))
+	#define wlan_outw_cpu_to_le16(v,a)	outw((v),(a))
+	#define wlan_outw_cpu_to_be16(v,a)	outw(__cpu_to_be16((v)), (a))
+	#define wlan_outl(v,a)			outl((v),(a))
+	#define wlan_outl_cpu_to_le32(v,a)	outl((v),(a))
+	#define wlan_outl_cpu_to_be32(v,a)	outl(__cpu_to_be32((v)), (a))
+#elif (WLAN_OS == WLAN_LINUX_KERNEL && WLAN_CPU_FAMILY == WLAN_PPC) 
+	#define wlan_inb(a)			inb((a))
+	#define wlan_inw(a)			in_be16((unsigned short *)((a)+_IO_BASE))
+	#define wlan_inw_le16_to_cpu(a)		inw((a))
+	#define wlan_inw_be16_to_cpu(a)		in_be16((unsigned short *)((a)+_IO_BASE))
+	#define wlan_inl(a)			in_be32((unsigned short *)((a)+_IO_BASE))
+	#define wlan_inl_le32_to_cpu(a)		inwl((a))
+	#define wlan_inl_be32_to_cpu(a)		in_be32((unsigned short *)((a)+_IO_BASE))
+
+	#define wlan_outb(v,a)			outb((v),(a))
+	#define wlan_outw(v,a)			out_be16((unsigned short *)((a)+_IO_BASE), (v))
+	#define wlan_outw_cpu_to_le16(v,a)	outw((v),(a))
+	#define wlan_outw_cpu_to_be16(v,a)	out_be16((unsigned short *)((a)+_IO_BASE), (v))
+	#define wlan_outl(v,a)			out_be32((unsigned short *)((a)+_IO_BASE), (v))
+	#define wlan_outl_cpu_to_le32(v,a)	outl((v),(a))
+	#define wlan_outl_cpu_to_be32(v,a)	out_be32((unsigned short *)((a)+_IO_BASE), (v))
 #endif
 
 /*=============================================================*/
@@ -551,6 +601,8 @@ typedef signed int      INT;
 #define wlan_max(a, b) (((a) > (b)) ? (a) : (b))
 #define wlan_min(a, b) (((a) < (b)) ? (a) : (b))
 
+#define WLAN_KVERSION(a,b,c)	(((a)<<16)+((b)<<8)+(c))
+
 /*=============================================================*/
 /*--- Variables -----------------------------------------------*/
 /*=============================================================*/
