@@ -1,7 +1,11 @@
-/* p80211knetdev.c: Linux Kernel net device interface
+/* src/p80211/p80211knetdev.c
+*
+* Linux Kernel net device interface
+*
+* Copyright (C) 1999 AbsoluteValue Systems, Inc.  All Rights Reserved.
 * --------------------------------------------------------------------
 *
-* Linux WLAN 
+* linux-wlan
 *
 *   The contents of this file are subject to the Mozilla Public
 *   License Version 1.1 (the "License"); you may not use this file
@@ -13,10 +17,6 @@
 *   implied. See the License for the specific language governing
 *   rights and limitations under the License.
 *
-*   The initial developer of the original code is Mark S. Mathews
-*   <mark@absoval.com>.  Portions created by Mark S. Mathews are 
-*   Copyright (C) 1999 AbsoluteValue Software, Inc.  All Rights Reserved.
-*
 *   Alternatively, the contents of this file may be used under the
 *   terms of the GNU Public License version 2 (the "GPL"), in which
 *   case the provisions of the GPL are applicable instead of the
@@ -30,9 +30,12 @@
 *
 * --------------------------------------------------------------------
 *
-* The initial author may be reached as mark@absoval.com, or 
-* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
-* Maitland, FL, 32794-1149
+* Inquiries regarding the linux-wlan Open Source project can be
+* made directly to:
+*
+* AbsoluteValue Systems Inc.
+* info@linux-wlan.com
+* http://www.linux-wlan.com
 *
 * --------------------------------------------------------------------
 *
@@ -218,10 +221,14 @@ int p80211knetdev_open( netdevice_t *netdev )
 	if ( wlandev->open != NULL) {
 		result = (*(wlandev->open))(wlandev);
 		if ( result == 0 ) {
+#if ( LINUX_VERSION_CODE < WLAN_KVERSION(2,3,43) )
 			/* set the device flags */
 			netdev->tbusy = 0;
 			netdev->interrupt = 0;
 			netdev->start = 1;
+#else
+			netif_start_queue(netdev);
+#endif
 		}
 	} else {
 		result = -EAGAIN;
@@ -255,10 +262,14 @@ int p80211knetdev_stop( netdevice_t *netdev )
 		result = (*(wlandev->close))(wlandev);
 	}
 
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
 	/* To make sure noone tries to send us something, just force */
 	/*  tbusy to true */
 	netdev->tbusy = 1;
 	netdev->start = 0;
+#else
+	netif_stop_queue(netdev);
+#endif
 
 	DBFEXIT;
 	return result;
@@ -287,9 +298,16 @@ void p80211netdev_rx(wlandevice_t *wlandev, wlan_pb_t *pb)
 
         DBFENTER;
 
-        dev->interrupt = 1;
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
         if (dev->start) {
-                if ( p80211pb_p80211_to_ether(wlandev, wlandev->ethconv, pb) == 0 ) {
+#else
+	if (dev->flags & IFF_UP ) {
+#endif
+		if ( pb->p80211_payloadlen == 0 ) {
+			/* Do nothing, converting and passing up zero 
+			   length frame is pointless 
+			*/
+		} else if ( p80211pb_p80211_to_ether(wlandev, wlandev->ethconv, pb) == 0 ) {
                         /* Mark last reception */
                         dev->last_rx = jiffies;
                         /* take ownership of skb from pb */
@@ -305,8 +323,6 @@ void p80211netdev_rx(wlandevice_t *wlandev, wlan_pb_t *pb)
 		}
         }
 
-        dev->interrupt = 0;
-
         p80211pb_free(pb);
 
         DBFEXIT;
@@ -341,79 +357,125 @@ int p80211knetdev_hard_start_xmit( struct sk_buff *skb, netdevice_t *netdev)
 
 	DBFENTER;
 
-	if ( netdev->start == 0 ) {
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
+        if (netdev->start == 0) {
+#else
+	if ((netdev->flags & IFF_UP) == 0 ) {
+#endif
 		return 1;
 	}
 
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
 	if ( test_and_set_bit(0, (void*)&(netdev->tbusy)) != 0 ) {
 		/* We've been called w/ tbusy set, has the tx */
 		/* path stalled?   */
 		WLAN_LOG_DEBUG0(1, "called when tbusy set\n");
+		return 1;
+	} 
+
+#else
+	netif_stop_queue(netdev);
+
+	/* No timeout handling here, 2.3.38+ kernels call the 
+	   timeout function directly.
+	*/
+#endif
+
+	/* particularly handy in the above case */
+	netdev->trans_start = jiffies;
+
+	/* Check to see that a valid mode is set */
+	switch( wlandev->macmode ) {
+	case WLAN_MACMODE_IBSS_STA: 
+	case WLAN_MACMODE_ESS_STA:
+	case WLAN_MACMODE_ESS_AP:
+		break;
+	default:
+		/* Mode isn't set yet, just drop the frame and return success */
+		/* TODO: we need a saner way to handle this */
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
+		netdev->tbusy = 0;
+#else
+		netif_wake_queue(netdev);
+#endif
+		dev_kfree_skb(skb);
+		WLAN_LOG_NOTICE0("Tx attempt prior to association, frame dropped.\n");
+		return 0;
+		break;
+	}
+		
+	/* OK, now we setup the ether to 802.11 conversion */
+	pb = p80211pb_alloc();
+	if ( pb == NULL ) {
+		return 1;
+	}
+
+	pb->ethhostbuf = skb;
+	pb->ethfree = p80211pb_freeskb;
+	pb->ethbuf = skb->data;
+	pb->ethbuflen = skb->len > 1514 ? 1514 : skb->len;
+	pb->ethfrmlen = pb->ethbuflen;
+	pb->eth_hdr = (wlan_ethhdr_t*)pb->ethbuf;
+
+	if ( p80211pb_ether_to_p80211(wlandev, wlandev->ethconv, pb) != 0 ) {
+		/* convert failed */
+		WLAN_LOG_DEBUG1(1, 
+			"ether_to_80211(%d) failed.\n", 
+			wlandev->ethconv);
+		/* Free the pb, but not the skb */
+		pb->ethhostbuf = NULL;
+		p80211pb_free(pb);
 		result = 1;
 	} else {
-		/* particularly handy in the above case */
-		netdev->trans_start = jiffies;
-
-		/* OK, now we setup the ether to 802.11 conversion */
-		pb = p80211pb_alloc();
-		if ( pb == NULL ) {
+		if ( wlandev->txframe == NULL ) {
 			return 1;
 		}
+		wlandev->linux_stats.tx_packets++;
 
-		pb->ethhostbuf = skb;
-		pb->ethfree = p80211pb_freeskb;
-		pb->ethbuf = skb->data;
-		pb->ethbuflen = skb->len > 1514 ? 1514 : skb->len;
-		pb->ethfrmlen = pb->ethbuflen;
-		pb->eth_hdr = (wlan_ethhdr_t*)pb->ethbuf;
+		txresult = (*(wlandev->txframe))(wlandev, pb);
 
-		if ( p80211pb_ether_to_p80211(wlandev, wlandev->ethconv, pb) != 0 ) {
-			/* convert failed */
-			WLAN_LOG_DEBUG1(1, 
-				"ether_to_80211(%d) failed.\n", 
-				wlandev->ethconv);
+		if ( txresult == 0) {
+  				/* success and more buf */
+			/* avail, re: hw_txdata */
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
+			netdev->tbusy = 0;
+#else
+			netif_wake_queue(netdev);
+#endif
+			result = 0;
+		} else if ( txresult == 1 ) { 
+			/* success, no more avail */
+			WLAN_LOG_DEBUG0(3, "txframe success, no more bufs\n");
+			/* netdev->tbusy = 1;  don't set here, irqhdlr */
+			/*   may have already cleared it */
+			result = 0;
+		} else if ( txresult == 2 ) { 
+			/* alloc failure, drop frame */
+			WLAN_LOG_DEBUG0(3, "txframe returned alloc_fail\n");
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
+			netdev->tbusy = 0;
+#else
+			netif_wake_queue(netdev);
+#endif
+			/* Free the pb, but not the skb */
+			pb->ethhostbuf = NULL;
+			p80211pb_free(pb);
+			result = 1;
+		} else { 
+			/* buffer full or queue busy */
+			WLAN_LOG_DEBUG0(3, "txframe returned full or busy\n");
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
+			netdev->tbusy = 0;
+#else
+			netif_wake_queue(netdev);
+#endif
 			/* Free the pb, but not the skb */
 			pb->ethhostbuf = NULL;
 			p80211pb_free(pb);
 			result = 1;
-		} else {
-			if ( wlandev->txframe == NULL ) {
-				return 1;
-			}
-			wlandev->linux_stats.tx_packets++;
-
-			txresult = (*(wlandev->txframe))(wlandev, pb);
-
-			if ( txresult == 0) {
-  				/* success and more buf */
-				/* avail, re: hw_txdata */
-				netdev->tbusy = 0;
-				result = 0;
-			} else if ( txresult == 1 ) { 
-				/* success, no more avail */
-				WLAN_LOG_DEBUG0(3, "txframe success, no more bufs\n");
-				/* netdev->tbusy = 1;  don't set here, irqhdlr */
-				/*   may have already cleared it */
-				result = 0;
-			} else if ( txresult == 2 ) { 
-				/* alloc failure, drop frame */
-				WLAN_LOG_DEBUG0(3, "txframe returned alloc_fail\n");
-				netdev->tbusy = 0;
-				/* Free the pb, but not the skb */
-				pb->ethhostbuf = NULL;
-				p80211pb_free(pb);
-				result = 1;
-			} else { 
-				/* buffer full or queue busy */
-				WLAN_LOG_DEBUG0(3, "txframe returned full or busy\n");
-				netdev->tbusy = 0;
-				/* Free the pb, but not the skb */
-				pb->ethhostbuf = NULL;
-				p80211pb_free(pb);
-				result = 1;
-			}
 		}
 	}
+
 	DBFEXIT;
 	return result;
 }
@@ -553,6 +615,8 @@ int wlan_setup(wlandevice_t *wlandev)
 		wlandev->ethconv = WLAN_ETHCONV_RFC1042;
 		wlandev->macmode = WLAN_MACMODE_NONE;
 
+		init_waitqueue_head(&wlandev->reqwq);
+
 		/* Allocate and initialize the struct device */
 		dev = kmalloc(sizeof(netdevice_t), GFP_ATOMIC);
 		if ( dev == NULL ) {
@@ -570,9 +634,12 @@ int wlan_setup(wlandevice_t *wlandev)
 			dev->open =		&p80211knetdev_open;
 			dev->stop =		&p80211knetdev_stop;
 
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,38) )
 			dev->tbusy = 1;
-
+#endif
+#if (LINUX_VERSION_CODE < WLAN_KVERSION(2,3,99) )
 			dev->name = wlandev->name;
+#endif
 			ether_setup(dev);
 		}
 	}
@@ -654,6 +721,10 @@ int register_wlandev(wlandevice_t *wlandev)
 		i = wlandev_get_index(wlandev);
 	}
 
+#if ( LINUX_VERSION_CODE >= WLAN_KVERSION(2,3,99) )
+	strcpy(dev->name, wlandev->name);
+#endif
+
 	if (register_netdevice(dev)) {
 		if ( i >= 0 ) {
 			wlandev_clear_index(wlandev);
@@ -663,6 +734,7 @@ int register_wlandev(wlandevice_t *wlandev)
 	}
 
 	rtnl_unlock();
+	MOD_INC_USE_COUNT;
 	DBFEXIT;
 	return 0;
 }
@@ -692,6 +764,7 @@ int unregister_wlandev(wlandevice_t *wlandev)
 	unregister_netdevice(wlandev->netdev);
 	wlandev_clear_index(wlandev);
 	rtnl_unlock();
+	MOD_DEC_USE_COUNT;
 	DBFEXIT;
 	return 0;
 }
