@@ -1,7 +1,11 @@
-/* prism2mgmt.c: Management request handler functions.
+/* src/prism2/driver/prism2mgmt.c
+*
+* Management request handler functions.
+*
+* Copyright (C) 1999 AbsoluteValue Systems, Inc.  All Rights Reserved.
 * --------------------------------------------------------------------
 *
-* Linux WLAN 
+* linux-wlan
 *
 *   The contents of this file are subject to the Mozilla Public
 *   License Version 1.1 (the "License"); you may not use this file
@@ -13,10 +17,6 @@
 *   implied. See the License for the specific language governing
 *   rights and limitations under the License.
 *
-*   The initial developer of the original code is Mark S. Mathews
-*   <mark@absoval.com>.  Portions created by Mark S. Mathews are 
-*   Copyright (C) 1999 AbsoluteValue Software, Inc.  All Rights Reserved.
-*
 *   Alternatively, the contents of this file may be used under the
 *   terms of the GNU Public License version 2 (the "GPL"), in which
 *   case the provisions of the GPL are applicable instead of the
@@ -30,9 +30,12 @@
 *
 * --------------------------------------------------------------------
 *
-* The initial author may be reached as mark@absoval.com, or 
-* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
-* Maitland, FL, 32794-1149
+* Inquiries regarding the linux-wlan Open Source project can be
+* made directly to:
+*
+* AbsoluteValue Systems Inc.
+* info@linux-wlan.com
+* http://www.linux-wlan.com
 *
 * --------------------------------------------------------------------
 *
@@ -149,17 +152,26 @@
 ----------------------------------------------------------------*/
 int prism2mgmt_powermgmt(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_powermgmt_t	*msg = msgp;
 	DBFENTER;
-
-#if defined(WLAN_STA)
+/*
+ * Set CNFPMENABLED (on or off)
+ * Set CNFMULTICASTRX (if PM on, otherwise clear)
+ * Spout a notice stating that SleepDuration and HoldoverDuration and PMEPS
+ * also have an impact.
+ */
 	/* Powermgmt is currently unsupported for STA */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 #elif defined(WLAN_AP)
+	int 			result = 0;
+	p80211msg_dot11req_powermgmt_t	*msg = msgp;
+	DBFENTER;
+
 	/* Powermgmt is never supported for AP */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -192,19 +204,79 @@ int prism2mgmt_powermgmt(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_scan(wlandevice_t *wlandev, void *msgp)
 {
+#if defined(WLAN_STA)
 	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
 	hfa384x_t		*hw = priv->hw;
 	int 			result = 0;
+	hfa384x_ScanRequest_data_t	scanreq;
 	p80211msg_dot11req_scan_t	*msg = msgp;
+	UINT16			word;
 	DBFENTER;
+#if 0
+	/* Check the roaming mode to make sure we can scan, change if necessary */
+	/* Check the port status, if disabled, then enable */
+	/* Construct the channel list */
+	/* Set the rate based on...what? */
+	if ( !joined )
+		rate=min(HFA384x_RID_TXRATECNTL) (aka dot11OperationalRates)
+	else
+		if ( dot11req_scan.ssid == currssid )
+			rate=max(HFA384x_RID_CNF_BASICRATES) 
+			   (if supported on STA..we might need to save 
+			   this from prior scans)
+		else
+			rate=min(HFA384x_RID_TXRATECNTL) (aka dot11OperationalRates)
+		endif
+	endif
+			
+	/* Set the scan command */
+	/* Issue the Inquire */
+	/* Sleep until scanresults are in */
+	/* Build the persistent (filtered) results */
 
-#if defined(WLAN_STA)
-	/* Scan is currently unsupported for STA (handled by f/w) */
-	/* TODO: there is f/w support for host managed scan, need */
-	/*       to implement */
+
+
+
+
+
+
+
+
+
+
+
+	word = 2;
+	hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFROAMINGMODE, &word);
+
+	/* Issue the scan request */
+	scanreq.channelList = host2hfa384x_16(0x07ff); /* scan channels 1-11 */
+	scanreq.txRate = host2hfa384x_16(BIT1);        /* probes @ 2Mb/s */
+	result = hfa384x_drvr_setconfig( hw, HFA384x_RID_SCANREQUEST,
+			&scanreq, HFA384x_RID_SCANREQUEST_LEN);
+	if ( result ) {
+		WLAN_LOG_ERROR1("setconfig(SCANREQUEST) failed. result=%d\n",
+				result);
+		result = 0;
+	}
+
+	/* Issue an inquire */
+	result = hfa384x_cmd_inquiry(hw, HFA384x_IT_SCANRESULTS);
+	if ( result ) {
+		WLAN_LOG_ERROR1("cmd_inquiry(SCANRESULTS) failed, result=%d.\n",
+				result);
+		result = 0;
+	}
+#endif
+	result = 0;
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+
 #elif defined(WLAN_AP)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
+	int 			result = 0;
+	p80211msg_dot11req_scan_t	*msg = msgp;
+	DBFENTER;
 	/* Scan is currently unsupported for AP */
 	/* TODO: Find out if host managed scan is supported in ap f/w */
 	/*       we might want to use it to allow some "auto config"  */
@@ -242,18 +314,24 @@ int prism2mgmt_scan(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_scan_results(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_scan_results_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* Same situation as scan */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 
 #elif defined(WLAN_AP)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
+	int 			result = 0;
+	p80211msg_dot11req_scan_results_t	*msg = msgp;
+	DBFENTER;
+
 	/* Same situation as scan */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -287,17 +365,21 @@ int prism2mgmt_scan_results(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_join(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_join_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* TODO: Implement after scan */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 #elif defined(WLAN_AP)
+	int	 			result = 0;
+	p80211msg_dot11req_join_t	*msg = msgp;
+	DBFENTER;
+
 	/* Never supported by APs */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -330,19 +412,23 @@ int prism2mgmt_join(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_authenticate(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_authenticate_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* TODO: Decide how we're going to handle this one w/ Prism2 */
 	/*       It could be entertaining since Prism2 doesn't have  */
 	/*       an explicit way to control this */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 #elif defined(WLAN_AP)
+	int		 			result = 0;
+	p80211msg_dot11req_authenticate_t	*msg = msgp;
+	DBFENTER;
+
 	/* Never supported by APs */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -375,20 +461,26 @@ int prism2mgmt_authenticate(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_deauthenticate(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_deauthenticate_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* TODO: Decide how we're going to handle this one w/ Prism2 */
 	/*       It could be entertaining since Prism2 doesn't have  */
 	/*       an explicit way to control this */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 #elif defined(WLAN_AP)
-	/* TODO: Decide how we're going to handle this one w/ Prism2 */
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
+	int 			result = 0;
+	p80211msg_dot11req_deauthenticate_t	*msg = msgp;
+	DBFENTER;
+
+	/* TODO: Decide how we're going to handle this one w/ Prism2. */
 	/*       It could be entertaining since Prism2 doesn't have  */
 	/*       an explicit way to control this */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
@@ -422,6 +514,7 @@ int prism2mgmt_deauthenticate(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_associate(wlandevice_t *wlandev, void *msgp)
 {
+#if defined(WLAN_STA)
 	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
 	hfa384x_t		*hw = priv->hw;
 	int 			result = 0;
@@ -430,7 +523,6 @@ int prism2mgmt_associate(wlandevice_t *wlandev, void *msgp)
 	p80211msg_dot11req_associate_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* Set the TxRates */
 	reg = 0x000f;
 	hfa384x_drvr_setconfig16(hw, HFA384x_RID_TXRATECNTL, &reg);
@@ -446,8 +538,8 @@ int prism2mgmt_associate(wlandevice_t *wlandev, void *msgp)
 		HFA384x_INTEN_TXEXC_SET(1) |
 		HFA384x_INTEN_TX_SET(1) |
 		HFA384x_INTEN_RX_SET(1);
-	outw( 0xffff, HFA384x_EVSTAT(priv->hw->iobase));
-	outw( reg, HFA384x_INTEN(hw->iobase));
+	wlan_outw_cpu_to_le16(0xffff, HFA384x_EVSTAT(priv->hw->iobase));
+	wlan_outw_cpu_to_le16(reg, HFA384x_INTEN(hw->iobase));
 		
 	/* Enable the Port */
 	hfa384x_cmd_enable(hw, 0);
@@ -457,6 +549,10 @@ int prism2mgmt_associate(wlandevice_t *wlandev, void *msgp)
 	msg->resultcode.data = P80211ENUM_resultcode_success;
 
 #elif defined(WLAN_AP)
+	int 				result = 0;
+	p80211msg_dot11req_associate_t	*msg = msgp;
+	DBFENTER;
+
 	/* Never supported on AP */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -489,17 +585,21 @@ int prism2mgmt_associate(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_reassociate(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_reassociate_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* TODO: Not supported yet...not sure how we're going to do it */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 #elif defined(WLAN_AP)
+	int 					result = 0;
+	p80211msg_dot11req_reassociate_t	*msg = msgp;
+	DBFENTER;
+
 	/* Never supported on AP */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -532,17 +632,23 @@ int prism2mgmt_reassociate(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_disassociate(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
+#if defined(WLAN_STA)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
 	int 			result = 0;
 	p80211msg_dot11req_disassociate_t	*msg = msgp;
 	DBFENTER;
 
-#if defined(WLAN_STA)
 	/* TODO: Not supported yet...not sure how we're going to do it */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
 #elif defined(WLAN_AP)
+/*	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw; */
+	int 			result = 0;
+	p80211msg_dot11req_disassociate_t	*msg = msgp;
+	DBFENTER;
+
 	/* TODO: Not supported yet...not sure how we're going to do it */
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
@@ -575,6 +681,18 @@ int prism2mgmt_disassociate(wlandevice_t *wlandev, void *msgp)
 ----------------------------------------------------------------*/
 int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 {
+#if defined(WLAN_STA)
+	int 				result = 0;
+	p80211msg_dot11req_start_t	*msg = msgp;
+	DBFENTER;
+
+
+	/* Ad-Hoc not quite supported on Prism2 */
+	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+	result = 0;
+
+#elif defined(WLAN_AP)
 	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
 	hfa384x_t		*hw = priv->hw;
 	int 			result = 0;
@@ -586,23 +704,15 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	UINT16			word;
 	DBFENTER;
 
-#if defined(WLAN_STA)
-
-	/* Ad-Hoc not quite supported on Prism2 */
-	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
-	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
-	result = 0;
-
-#elif defined(WLAN_AP)
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
 
 	/* Validate the command, if BSStype=infra is the tertiary loaded? */
-	if ( (msg->bsstype.data == P80211ENUM_bsstype_independent && 
-	      priv->cap_sup_sta.id != 4) ||
-	     (msg->bsstype.data == P80211ENUM_bsstype_infrastructure && 
-	      priv->cap_sup_sta.id != 5) ) {
-		msg->resultcode.data = P80211ENUM_resultcode_invalid_parameters;
-		return 0;
+	if ( msg->bsstype.data == P80211ENUM_bsstype_independent ) {
+		WLAN_LOG_ERROR0("AP driver cannot create IBSS.\n");
+		goto failed;
+	} else if ( priv->cap_sup_sta.id != 5) {
+		WLAN_LOG_ERROR0("AP driver failed to detect AP firmware.\n");
+		goto failed;
 	}
 
 	/* Set the REQUIRED config items */
@@ -612,25 +722,17 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	result = hfa384x_drvr_setconfig( hw, HFA384x_RID_CNFOWNSSID,
 				bytebuf, HFA384x_RID_CNFOWNSSID_LEN);
 	if ( result ) {
-		WLAN_LOG_DEBUG0(1, "Unable to set SSID\n");
+		WLAN_LOG_ERROR0("Failed to set SSID\n");
 		goto failed;
 	}
 
-	/* bsstype */
-	if ( msg->bsstype.data == P80211ENUM_bsstype_independent ) {
-		word = HFA384x_PORTTYPE_IBSS;
-		result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFPORTTYPE, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1, "Unable to set port type=%d.\n", word);
-			goto failed;
-		}
-	}
+	/* bsstype - we use the default in the ap firmware */
 
 	/* beacon period */
 	word = msg->beaconperiod.data;
 	result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFAPBCNINT, &word);
 	if ( result ) {
-		WLAN_LOG_DEBUG1(1, "Unable to set beacon period=%d.\n", word);
+		WLAN_LOG_ERROR1("Failed to set beacon period=%d.\n", word);
 		goto failed;
 	}
 
@@ -638,7 +740,7 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	word = msg->dschannel.data;
 	result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFOWNCHANNEL, &word);
 	if ( result ) {
-		WLAN_LOG_DEBUG1(1, "Unable to set channel=%d.\n", word);
+		WLAN_LOG_ERROR1("Failed to set channel=%d.\n", word);
 		goto failed;
 	}
 	/* Basic rates */
@@ -666,12 +768,12 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	}
 	result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFBASICRATES, &word);
 	if ( result ) {
-		WLAN_LOG_DEBUG1(1, "Unable to set basicrates=%d.\n", word);
+		WLAN_LOG_ERROR1("Failed to set basicrates=%d.\n", word);
 		goto failed;
 	}
 
 	/* Operational rates (supprates and txratecontrol) */
-	word = msg->operationalrate1.data;
+	word = p80211rate_to_p2bit(msg->operationalrate1.data);
 	if ( msg->operationalrate2.status == P80211ENUM_msgitem_status_data_ok ) {
 		word |= p80211rate_to_p2bit(msg->operationalrate2.data);
 	}
@@ -693,53 +795,30 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	if ( msg->operationalrate8.status == P80211ENUM_msgitem_status_data_ok ) {
 		word |= p80211rate_to_p2bit(msg->operationalrate8.data);
 	}
-	if ( msg->bsstype.data == P80211ENUM_bsstype_infrastructure ) {
-		result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFSUPPRATES, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1, "Unable to set supprates=%d.\n", word);
-			goto failed;
-		}
-		result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_TXRATECNTL0, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1, "Unable to set txrates=%d.\n", word);
-			goto failed;
-		}
-	} else { /* assume ibss */
-		result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_TXRATECNTL, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1, "Unable to set txrates=%d.\n", word);
-			goto failed;
-		}
+	result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFSUPPRATES, &word);
+	if ( result ) {
+		WLAN_LOG_ERROR1("Failed to set supprates=%d.\n", word);
+		goto failed;
+	}
+	result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_TXRATECNTL0, &word);
+	if ( result ) {
+		WLAN_LOG_ERROR1("Failed to set txrates=%d.\n", word);
+		goto failed;
 	}
 
 	/* ibssatimwindow */
-	if (msg->bsstype.data != P80211ENUM_bsstype_independent ) {
-		WLAN_LOG_INFO0("Setting atimwindow for non-ibss is pointless.\n");
-	} else {
-		word = msg->ibssatimwindow.data;
-		result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFOWNATIMWIN, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1, "Unable to set atimwindow=%d.\n", word);
-			goto failed;
-		}
-	}
-
-	/* The settings below this if statement only apply to infrastructure */
-	/*  if we're not infrastructure, skip over them */
-	if (msg->bsstype.data != P80211ENUM_bsstype_infrastructure ) {
-		goto ibss_skip;
-	}
+	WLAN_LOG_INFO0("atimwindow not used in Infrastructure mode, ignored.\n");
 
 	/* DTIM period */
 	word = msg->dtimperiod.data;
 	result = hfa384x_drvr_setconfig16(hw, HFA384x_RID_CNFOWNDTIMPER, &word);
 	if ( result ) {
-		WLAN_LOG_DEBUG1(1, "Unable to set dtim period=%d.\n", word);
+		WLAN_LOG_ERROR1("Failed to set dtim period=%d.\n", word);
 		goto failed;
 	}
 
 	/* probedelay */
-	WLAN_LOG_INFO0("No setting for probedelay in prism2, skipped.\n");
+	WLAN_LOG_INFO0("prism2mgmt_start: probedelay not supported in prism2, ignored.\n");
 
 	/* cfpollable, cfpollreq, cfpperiod, cfpmaxduration */
 	if (msg->cfpollable.data == P80211ENUM_truth_true && 
@@ -753,8 +832,10 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	result = hfa384x_drvr_getconfig(hw, HFA384x_RID_CNFAPPCFINFO, 
 					pcfinfo, HFA384x_RID_CNFAPPCFINFO_LEN);
 	if ( result ) {
-		WLAN_LOG_DEBUG0(1, "Unable to read pcfinfo, not supported so skip it.\n");
-		goto ibss_skip;
+		WLAN_LOG_INFO0("prism2mgmt_start: read(pcfinfo) failed, "
+				"assume it's "
+				"not supported, pcf settings ignored.\n");
+		goto pcf_skip;
 	}
 	if ((msg->cfpollable.data == P80211ENUM_truth_false && 
 	     msg->cfpollreq.data == P80211ENUM_truth_false) ) {
@@ -790,22 +871,21 @@ int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
 	result = hfa384x_drvr_setconfig(hw, HFA384x_RID_CNFAPPCFINFO, 
 					pcfinfo, HFA384x_RID_CNFAPPCFINFO_LEN);
 	if ( result ) {
-		WLAN_LOG_DEBUG0(1, "Unable to write pcfinfo, not supported so skip it.\n");
-		/* goto failed; */
+		WLAN_LOG_ERROR0("write(pcfinfo) failed.\n");
+		goto failed;
 	}
 
-
-ibss_skip:
-
+pcf_skip:
 	/* Enable the interrupts */
 	word = HFA384x_INTEN_INFDROP_SET(1) |
 		HFA384x_INTEN_INFO_SET(1) |
 		HFA384x_INTEN_ALLOC_SET(1) |
 		HFA384x_INTEN_TXEXC_SET(1) |
+		HFA384x_INTEN_DTIM_SET(1) |
 		HFA384x_INTEN_TX_SET(1) |
 		HFA384x_INTEN_RX_SET(1);
-	outw( 0xffff, HFA384x_EVSTAT(priv->hw->iobase));
-	outw( word, HFA384x_INTEN(hw->iobase));
+	wlan_outw_cpu_to_le16(0xffff, HFA384x_EVSTAT(priv->hw->iobase));
+	wlan_outw_cpu_to_le16(word, HFA384x_INTEN(hw->iobase));
 
 	/* Set the macmode so the frame setup code knows what to do */
 	if ( msg->bsstype.data == P80211ENUM_bsstype_infrastructure ) {
@@ -820,7 +900,7 @@ ibss_skip:
 	/* Enable the Port */
 	result = hfa384x_cmd_enable(hw, 0);
 	if ( result ) {
-		WLAN_LOG_DEBUG1(1, "Enable macport failed, result=%d.\n", result);
+		WLAN_LOG_ERROR1("Enable macport failed, result=%d.\n", result);
 		goto failed;
 	}
 	
@@ -1026,6 +1106,121 @@ int prism2mgmt_auxport_write(wlandevice_t *wlandev, void *msgp)
 	return 0;
 }
 
+/*----------------------------------------------------------------
+* prism2mgmt_test_command
+*
+* Puts the card into the desired test mode.
+*
+* Arguments:
+*	wlandev		wlan device structure
+*	msgp		ptr to msg buffer
+*
+* Returns: 
+*	0	success and done
+*	<0	success, but we're waiting for something to finish.
+*	>0	an error occurred while handling the message.
+* Side effects:
+*
+* Call context:
+*	process thread  (usually)
+----------------------------------------------------------------*/
+int prism2mgmt_test_command(wlandevice_t *wlandev, void *msgp)
+{
+	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw;
+	p80211msg_p2req_test_command_t	*msg = msgp;
+	DBFENTER;
+
+	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
+
+	/* call some routine to execute the test command */
+
+	hfa384x_drvr_test_command(hw, msg->testcode.data, msg->testparam.data);
+
+	msg->resultcode.data = P80211ENUM_resultcode_success;
+
+	DBFEXIT;
+	return 0;
+}
+
+/*----------------------------------------------------------------
+* prism2mgmt_mmi_read
+*
+* Read from one of the MMI registers.
+*
+* Arguments:
+*	wlandev		wlan device structure
+*	msgp		ptr to msg buffer
+*
+* Returns: 
+*	0	success and done
+*	<0	success, but we're waiting for something to finish.
+*	>0	an error occurred while handling the message.
+* Side effects:
+*
+* Call context:
+*	process thread  (usually)
+----------------------------------------------------------------*/
+int prism2mgmt_mmi_read(wlandevice_t *wlandev, void *msgp)
+{
+	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw;
+	p80211msg_p2req_mmi_read_t	*msg = msgp;
+
+	DBFENTER;
+
+	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
+
+	/* call some routine to execute the test command */
+
+	hfa384x_drvr_mmi_read(hw, msg->addr.data);
+
+	/* I'm not sure if this is "architecturally" correct, but it
+           is expedient. */
+
+	msg->value.data = (UINT32) hw->resp0;
+	msg->resultcode.data = P80211ENUM_resultcode_success;
+
+	DBFEXIT;
+	return 0;
+}
+
+/*----------------------------------------------------------------
+* prism2mgmt_mmi_write
+*
+* Write a data value to one of the MMI registers.
+*
+* Arguments:
+*	wlandev		wlan device structure
+*	msgp		ptr to msg buffer
+*
+* Returns: 
+*	0	success and done
+*	<0	success, but we're waiting for something to finish.
+*	>0	an error occurred while handling the message.
+* Side effects:
+*
+* Call context:
+*	process thread  (usually)
+----------------------------------------------------------------*/
+int prism2mgmt_mmi_write(wlandevice_t *wlandev, void *msgp)
+{
+	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t		*hw = priv->hw;
+	p80211msg_p2req_mmi_write_t	*msg = msgp;
+	DBFENTER;
+
+	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
+
+	/* call some routine to execute the test command */
+
+	hfa384x_drvr_mmi_write(hw, msg->addr.data, msg->data.data);
+
+	msg->resultcode.data = P80211ENUM_resultcode_success;
+
+	DBFEXIT;
+	return 0;
+}
 
 /*----------------------------------------------------------------
 * prism2mgmt_ramdl_state
@@ -1234,11 +1429,9 @@ int prism2mgmt_flashdl_write(wlandevice_t *wlandev, void *msgp)
 
 
 /*----------------------------------------------------------------
-* prism2mgmt_mm_state
+* prism2mgmt_mm_dscpmap
 *
-* Enables the usage of the QoS parameter to the transmit 
-* command.  Also sets (for now) a variable that contains a static
-* QoS value to use for all transmitted frames.
+* Maps a given diffserv level to one of the output queues.
 *
 * Arguments:
 *	wlandev		wlan device structure
@@ -1253,22 +1446,15 @@ int prism2mgmt_flashdl_write(wlandevice_t *wlandev, void *msgp)
 * Call context:
 *	process thread  (usually)
 ----------------------------------------------------------------*/
-int prism2mgmt_mm_state(wlandevice_t *wlandev, void *msgp)
+int prism2mgmt_mm_dscpmap(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	p80211msg_p2req_mm_state_t	*msg = msgp;
+	prism2sta_priv_t		*priv = (prism2sta_priv_t*)wlandev->priv;
+	p80211msg_p2req_mm_dscpmap_t	*msg = msgp;
 	DBFENTER;
 
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
-	if  ( msg->enable.data == P80211ENUM_truth_true) {
-		priv->qos_enable = 1;
-		priv->qos_staticlevel = msg->level.data;
-		msg->resultcode.status = P80211ENUM_resultcode_success;
-	} else {
-		priv->qos_enable = 0;
-		priv->qos_staticlevel = 0;
-		msg->resultcode.status = P80211ENUM_resultcode_success;
-	}
+	msg->resultcode.data = P80211ENUM_resultcode_success;
+	priv->qos_dscpmap[msg->dscp.data] = msg->macqueue.data;
 
 	DBFEXIT;
 	return 0;
@@ -1276,9 +1462,10 @@ int prism2mgmt_mm_state(wlandevice_t *wlandev, void *msgp)
 
 
 /*----------------------------------------------------------------
-* prism2mgmt_wlansniff
+* prism2mgmt_dump_state
 *
-* Start or stop sniffing.
+* Dumps the driver's and hardware's current state via the kernel 
+* log at KERN_NOTICE level.
 *
 * Arguments:
 *	wlandev		wlan device structure
@@ -1292,182 +1479,34 @@ int prism2mgmt_mm_state(wlandevice_t *wlandev, void *msgp)
 *
 * Call context:
 *	process thread  (usually)
-*	interrupt
 ----------------------------------------------------------------*/
-int prism2mgmt_wlansniff(wlandevice_t *wlandev, void *msgp)
+int prism2mgmt_dump_state(wlandevice_t *wlandev, void *msgp)
 {
-	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
-	hfa384x_t		*hw = priv->hw;
-	int 			result = 0;
-	p80211msg_lnxreq_wlansniff_t	*msg = msgp;
-	UINT16			word;
-
+	prism2sta_priv_t		*priv = (prism2sta_priv_t*)wlandev->priv;
+	hfa384x_t			*hw = priv->hw;
+	p80211msg_p2req_dump_state_t	*msg = msgp;
+	int				result;
+	UINT16				auxbuf[15];
 	DBFENTER;
 
 	msg->resultcode.status = P80211ENUM_msgitem_status_data_ok;
+	msg->resultcode.data = P80211ENUM_resultcode_success;
 
-	switch (msg->enable.data)
-	{
-	case P80211ENUM_truth_false:
-		/* Confirm that we're in monitor mode */
-		if ( !priv->sniffing ) {
-			msg->resultcode.data = P80211ENUM_resultcode_invalid_parameters;
-			result = 0;
-		}
-		/* Disable monitor mode */
-		result = hfa384x_cmd_monitor(hw, HFA384x_MONITOR_DISABLE);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1,
-				"failed to disable monitor mode, result=%d\n", 
-				result);
-			goto failed;
-		}
-		/* Disable port 0 */
-		result = hfa384x_cmd_disable(hw, 0);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1,
-			"failed to disable port 0 after sniffing, result=%d\n", 
-			result);
-			goto failed;
-		}
-		/* Clear the driver state */
-		priv->sniffing = 0;
-
-		/* Restore the wepflags */
-		result = hfa384x_drvr_setconfig16(hw, 
-				HFA384x_RID_CNFWEPFLAGS, 
-				&(priv->presniff_wepflags));
-		if ( result ) {
-			WLAN_LOG_DEBUG2(1,
-			"failed to restore wepflags=0x%04x, result=%d\n", 
-			word,
-			result);
-			goto failed;
-		}
-		/* Set the port to its prior type and enable (if necessary) */
-		if (priv->presniff_port_type != 0 ) {
-			word = priv->presniff_port_type;
-			result = hfa384x_drvr_setconfig16(hw, 
-				HFA384x_RID_CNFPORTTYPE, &word);
-			if ( result ) {
-				WLAN_LOG_DEBUG1(1,
-				"failed to restore porttype, result=%d\n", 
-				result);
-				goto failed;
-			}
-			/* Enable the port */
-			result = hfa384x_cmd_enable(hw, 0);
-			if ( result ) {
-				WLAN_LOG_DEBUG1(1,
-				"failed to enable port to presniff setting, result=%d\n", 
-				result);
-				goto failed;
-			}
-		}
-
-		msg->resultcode.data = P80211ENUM_resultcode_success;
-		result = 0;
-		goto exit;
-		break;
-	case P80211ENUM_truth_true:
-		/* Disable the port (if enabled), only check Port 0 */
-		if ( hw->port_enabled[0] ) {
-			/* Save macport 0 state */
-			result = hfa384x_drvr_getconfig16(hw,
-					HFA384x_RID_CNFPORTTYPE,
-					&(priv->presniff_port_type));
-			if ( result ) {
-				WLAN_LOG_DEBUG1(1,"failed to read porttype, result=%d\n", result);
-				goto failed;
-			}
-			/* Save the wepflags state */
-			result = hfa384x_drvr_getconfig16(hw,
-					HFA384x_RID_CNFWEPFLAGS,
-					&(priv->presniff_wepflags));
-			if ( result ) {
-				WLAN_LOG_DEBUG1(1,"failed to read wepflags, result=%d\n", result);
-				goto failed;
-			}
-			result = hfa384x_cmd_disable(hw, 0);
-			if ( result ) {
-				WLAN_LOG_DEBUG1(1,
-				"failed to clear port 0 for sniffing, result=%d\n", 
-				result);
-				goto failed;
-			}
-		}
-		else {
-			priv->presniff_port_type = 0;
-		}
-		/* Set the channel we wish to sniff */
-		word = msg->channel.data;
-		result = hfa384x_drvr_setconfig16(hw, 
-				HFA384x_RID_CNFOWNCHANNEL, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG2(1,
-			"failed to set channel %d, result=%d\n", 
-			word,
-			result);
-			goto failed;
-		}
-		/* Set the port type to pIbss */
-		word = HFA384x_PORTTYPE_IBSS;
-		result = hfa384x_drvr_setconfig16(hw, 
-				HFA384x_RID_CNFPORTTYPE, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG2(1,
-			"failed to set porttype %d, result=%d\n", 
-			word,
-			result);
-			goto failed;
-		}
-		/* Set the wepflags for no decryption */
-		word =	HFA384x_WEPFLAGS_DISABLE_TXCRYPT | 
-			HFA384x_WEPFLAGS_DISABLE_RXCRYPT;
-		result = hfa384x_drvr_setconfig16(hw, 
-				HFA384x_RID_CNFWEPFLAGS, &word);
-		if ( result ) {
-			WLAN_LOG_DEBUG2(1,
-			"failed to set wepflags=0x%04x, result=%d\n", 
-			word,
-			result);
-			goto failed;
-		}
-		/* Enable the port */
-		result = hfa384x_cmd_enable(hw, 0);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1,
-			"failed to enable port for sniffing, result=%d\n", 
-			result);
-			goto failed;
-		}
-		/* Enable monitor mode */
-		result = hfa384x_cmd_monitor(hw, HFA384x_MONITOR_ENABLE);
-		if ( result ) {
-			WLAN_LOG_DEBUG1(1,
-			"failed to enable monitor mode, result=%d\n", 
-			result);
-			goto failed;
-		}
-		/* Set the driver state */
-		priv->sniffing = 1;
-
-		msg->resultcode.data = P80211ENUM_resultcode_success;
-		result = 0;
-		goto exit;
-		break;
-	default:
-		msg->resultcode.data = P80211ENUM_resultcode_invalid_parameters;
-		result = 0;
-		goto exit;
-		break;
+	WLAN_LOG_NOTICE0("prism2 driver and hardware state:\n");
+	if  ( (result = hfa384x_cmd_aux_enable(hw)) ) {
+		WLAN_LOG_ERROR1("aux_enable failed, result=%d\n", result);
+		goto failed;
 	}
+	hfa384x_copy_from_aux(hw, 0x01e2, auxbuf, sizeof(auxbuf));
+	hfa384x_cmd_aux_disable(hw);
+	WLAN_LOG_NOTICE1("  cmac: FreeBlocks=%d\n", auxbuf[5]);
+	WLAN_LOG_NOTICE2("  cmac: IntEn=0x%02x EvStat=0x%02x\n", 
+		wlan_inw_le16_to_cpu(HFA384x_INTEN(hw->iobase)),
+		wlan_inw_le16_to_cpu(HFA384x_EVSTAT(hw->iobase)));
+	WLAN_LOG_NOTICE2("  drvr: txfid_top=%d stacksize=%d\n",
+		priv->txfid_top,PRISM2_FIDSTACKLEN_MAX);
 
-failed:
-	msg->resultcode.data = P80211ENUM_resultcode_refused;
-	result = 0;
-exit:	
+failed:	
 	DBFEXIT;
-	return result;
+	return 0;
 }
-
