@@ -1,7 +1,11 @@
-/* prism2mib.c: Management request for mibset/mibget
+/* src/prism2/driver/prism2mib.c
+*
+* Management request for mibset/mibget
+*
+* Copyright (C) 1999 AbsoluteValue Systems, Inc.  All Rights Reserved.
 * --------------------------------------------------------------------
 *
-* Linux WLAN 
+* linux-wlan
 *
 *   The contents of this file are subject to the Mozilla Public
 *   License Version 1.1 (the "License"); you may not use this file
@@ -13,10 +17,6 @@
 *   implied. See the License for the specific language governing
 *   rights and limitations under the License.
 *
-*   The initial developer of the original code is Mark S. Mathews
-*   <mark@absoval.com>.  Portions created by Mark S. Mathews are 
-*   Copyright (C) 1999 AbsoluteValue Software, Inc.  All Rights Reserved.
-*
 *   Alternatively, the contents of this file may be used under the
 *   terms of the GNU Public License version 2 (the "GPL"), in which
 *   case the provisions of the GPL are applicable instead of the
@@ -30,9 +30,12 @@
 *
 * --------------------------------------------------------------------
 *
-* The initial author may be reached as mark@absoval.com, or 
-* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
-* Maitland, FL, 32794-1149
+* Inquiries regarding the linux-wlan Open Source project can be
+* made directly to:
+*
+* AbsoluteValue Systems Inc.
+* info@linux-wlan.com
+* http://www.linux-wlan.com
 *
 * --------------------------------------------------------------------
 *
@@ -375,9 +378,9 @@ case DIDmib_dot11smt_dot11StationConfigTable_dot11DesiredSSID:
 case DIDmib_dot11smt_dot11StationConfigTable_dot11DesiredBSSType:
 #if defined(WLAN_STA)
 	if ( isget ) {
-		*uint32 = priv->desired_bss_type;
+		*uint32 = priv->dot11_desired_bss_type;
 	} else {
-		priv->desired_bss_type = *uint32;
+		priv->dot11_desired_bss_type = *uint32;
 	}
 #elif defined(WLAN_AP)
 	/* MIB not supported on APs */
@@ -474,6 +477,78 @@ case DIDmib_dot11smt_dot11StationConfigTable_dot11AssociationResponseTimeOut:
 	break;
 
 
+/*----------------------------------------------------------------*/
+case DIDmib_dot11smt_dot11StationConfigTable_dot11DisassociateReason:
+	/* Supported in both STA and AP */
+	if ( isget ) {
+		*uint32 = priv->dot11_disassoc_reason;
+	} else {
+		msg->resultcode.data = 
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+
+/*----------------------------------------------------------------*/
+case DIDmib_dot11smt_dot11StationConfigTable_dot11DisassociateStation:
+	/* Supported in both STA and AP */
+	if ( isget ) {
+		memcpy(pstr->data, priv->dot11_disassoc_station, WLAN_ADDR_LEN);
+		pstr->len = WLAN_ADDR_LEN;
+	} else {
+		msg->resultcode.data = 
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_dot11smt_dot11StationConfigTable_dot11DeauthenticateReason:
+	/* Supported in both STA and AP */
+	if ( isget ) {
+		*uint32 = priv->dot11_deauth_reason;
+	} else {
+		msg->resultcode.data = 
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+
+/*----------------------------------------------------------------*/
+case DIDmib_dot11smt_dot11StationConfigTable_dot11DeauthenticateStation:
+	/* Supported in both STA and AP */
+	if ( isget ) {
+		memcpy(pstr->data, priv->dot11_deauth_station, WLAN_ADDR_LEN);
+		pstr->len = WLAN_ADDR_LEN;
+	} else {
+		msg->resultcode.data = 
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_dot11smt_dot11StationConfigTable_dot11AuthenticateFailStatus:
+	/* Supported in both STA and AP */
+	if ( isget ) {
+		*uint32 = priv->dot11_auth_fail_status;
+	} else {
+		msg->resultcode.data = 
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+
+/*----------------------------------------------------------------*/
+case DIDmib_dot11smt_dot11StationConfigTable_dot11AuthenticateFailStation:
+	/* Supported in both STA and AP */
+	if ( isget ) {
+		memcpy(pstr->data, priv->dot11_auth_fail_station, WLAN_ADDR_LEN);
+		pstr->len = WLAN_ADDR_LEN;
+	} else {
+		msg->resultcode.data = 
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
 /*----------------------------------------------------------------*/
 case DIDmib_dot11mac_dot11OperationTable_dot11MACAddress:
 	/* Supported in both STA and AP */
@@ -660,20 +735,20 @@ case DIDmib_dot11mac_dot11GroupAddressesTable_dot11Address32:
 	} else {
 		if ( (result = prism2mgmt_set_grpaddr(mibitem->did, bytebuf,
 			pstr, priv)) == 0 ) {
-			if ( (priv->grpcnt) <= MAX_PRISM2_GRP_ADDR ) {
+			if ( (priv->dot11_grpcnt) <= MAX_PRISM2_GRP_ADDR ) {
 				memcpy( bytebuf,
-					priv->grp_addr[0],
-					((priv->grpcnt) * WLAN_ADDR_LEN));
+					priv->dot11_grp_addr[0],
+					((priv->dot11_grpcnt) * WLAN_ADDR_LEN));
 				result = hfa384x_drvr_setconfig( hw,
 					HFA384x_RID_GROUPADDR,
 					bytebuf,
-					((priv->grpcnt) * WLAN_ADDR_LEN));
+					((priv->dot11_grpcnt) * WLAN_ADDR_LEN));
 
 				/* turn off promiscuous mode if count is
 				equal to MAX; we may have been at a higher
 				count in promiscuous mode and need to turn
 				it off. */
-				if ( (priv->grpcnt) == MAX_PRISM2_GRP_ADDR ) {
+				if ( (priv->dot11_grpcnt) == MAX_PRISM2_GRP_ADDR ) {
 					*wordbuf = 0;
 					result = hfa384x_drvr_setconfig16( hw,
 						HFA384x_RID_PROMISCMODE,
@@ -1149,18 +1224,6 @@ case DIDmib_p2_p2Table_p2MMTx:
 	}
 	break;
 
-/*----------------------------------------------------------------*/
-case DIDmib_p2_p2Table_p2MMFixedLevel:
-	/* Supported in both STA and AP */
-	if ( isget ) {
-		*uint32 = priv->qos_staticlevel;
-		result = 0;
-	} else {
-		priv->qos_staticlevel = *uint32;
-		result = 0;
-	}
-	break;
-
 /*----------------------------------------------------------------*/
 case DIDmib_p2_p2Table_p2TxControlDepth:
 #if defined(WLAN_STA)
@@ -1181,6 +1244,355 @@ case DIDmib_p2_p2Table_p2TxControlDepth:
 #endif
 	break;
 
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2RoamingMode:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFROAMINGMODE, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		prism2mgmt_p80211int2prism2int(wordbuf, uint32);
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFROAMINGMODE, wordbuf);
+	}
+#elif defined(WLAN_AP)
+	/* MIB not supported on APs */
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#else
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2CurrBSSID:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_CURRENTBSSID, bytebuf, 
+				HFA384x_RID_CNFOWNMACADDR_LEN);
+		prism2mgmt_bytearea2pstr(bytebuf, 
+			pstr, HFA384x_RID_CNFOWNMACADDR_LEN);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+#elif defined(WLAN_AP)
+	/* MIB not supported on APs */
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#else
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2SystemScale:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFSYSSCALE, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		prism2mgmt_p80211int2prism2int(wordbuf, uint32);
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFSYSSCALE, wordbuf);
+	}
+#elif defined(WLAN_AP)
+	/* MIB not supported on APs */
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2MaxDataLen:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFMAXDATALEN, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		prism2mgmt_p80211int2prism2int(wordbuf, uint32);
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFMAXDATALEN, wordbuf);
+	}
+#elif defined(WLAN_AP)
+	/* MIB not supported on APs */
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+/* NOTE: cnfPMEnable should be implemented as part of the dot11req_powermgmt */
+
+case DIDmib_p2_p2Table_p2EnhancePowerSaveMode:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFPMEPS, wordbuf);
+		*uint32 = *wordbuf ?
+			P80211ENUM_truth_true: P80211ENUM_truth_false;
+	} else {
+		*wordbuf = *uint32 == P80211ENUM_truth_true ? 1 : 0;
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFPMEPS, wordbuf);
+		if ( result ) {
+			WLAN_LOG_DEBUG0(1,"Unable to write CNFPMEPS");
+		}
+	}
+#elif defined(WLAN_AP)
+	/* MIB not supported on APs */
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+/* Tells the MAC to 'rx mcast when PM is enabled'.  I'm assuming
+ * this is identical to the 802.11 powermgt.request argument 
+ * "ReceiveDTIMS".  Therefore, this one is implemented via the 
+ * powermgmt.request primitive.
+ */
+#if 0
+case DIDmib_p2_p2Table_p2MulticastRx:
+#if defined(WLAN_STA)
+#elif defined(WLAN_AP)
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+#endif
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2MaxSleepDuration:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFMAXSLEEPDUR, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		prism2mgmt_p80211int2prism2int(wordbuf, uint32);
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFMAXSLEEPDUR, wordbuf);
+	}
+#elif defined(WLAN_AP)
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2PMHoldoverDuration:
+#if defined(WLAN_STA)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFPMHOLDDUR, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		prism2mgmt_p80211int2prism2int(wordbuf, uint32);
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFPMHOLDDUR, wordbuf);
+	}
+#elif defined(WLAN_AP)
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2OwnName:
+	/* Defined for STA and AP */
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, HFA384x_RID_CNFOWNNAME,
+			bytebuf, HFA384x_RID_CNFDESIREDSSID_LEN);
+		prism2mgmt_bytestr2pstr(p2bytestr, pstr);
+	} else {
+		prism2mgmt_pstr2bytestr(p2bytestr, pstr);
+		result = hfa384x_drvr_setconfig( hw, HFA384x_RID_CNFOWNNAME,
+			bytebuf, HFA384x_RID_CNFDESIREDSSID_LEN);
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2McastPMBuffer:
+#if defined(WLAN_STA)
+	msg->resultcode.data = P80211ENUM_resultcode_not_supported;
+#elif defined(WLAN_AP)
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CNFMCASTPMBUFF, wordbuf);
+		*uint32 = *wordbuf ?
+			P80211ENUM_truth_true: P80211ENUM_truth_false;
+	} else {
+		*wordbuf = *uint32 == P80211ENUM_truth_true ? 1 : 0;
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_CNFMCASTPMBUFF, wordbuf);
+		if ( result ) {
+			WLAN_LOG_DEBUG0(1,"Unable to write CNFMCASTPMBUFF");
+		}
+	}
+#elif
+#error "WLAN_STA or WLAN_AP not defined!"
+#endif
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2TickTime:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_ITICKTIME, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		prism2mgmt_p80211int2prism2int(wordbuf, uint32);
+		result = hfa384x_drvr_setconfig16( hw, 
+				HFA384x_RID_ITICKTIME, wordbuf);
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2MaxLoadTime:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_MAXLOADTIME, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2DLBufferPage:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_DOWNLOADBUFFER, bytebuf, 
+				HFA384x_RID_DOWNLOADBUFFER_LEN);
+		*uint32 = hfa384x2host_16(((hfa384x_downloadbuffer_t *)bytebuf)->page);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2DLBufferOffset:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_DOWNLOADBUFFER, bytebuf, 
+				HFA384x_RID_DOWNLOADBUFFER_LEN);
+		*uint32 = hfa384x2host_16(((hfa384x_downloadbuffer_t *)bytebuf)->offset);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2DLBufferLength:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_DOWNLOADBUFFER, bytebuf, 
+				HFA384x_RID_DOWNLOADBUFFER_LEN);
+		*uint32 = hfa384x2host_16(((hfa384x_downloadbuffer_t *)bytebuf)->len);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2PortStatus:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_PORTSTATUS, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+	
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2CommsQualityCQ:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_COMMSQUALITY, bytebuf, 
+				HFA384x_RID_COMMSQUALITY_LEN);
+		*uint32 = hfa384x2host_16(((hfa384x_commsquality_t *)bytebuf)->CQ_currBSS);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2CommsQualityASL:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_COMMSQUALITY, bytebuf, 
+				HFA384x_RID_COMMSQUALITY_LEN);
+		*uint32 = hfa384x2host_16(((hfa384x_commsquality_t *)bytebuf)->ASL_currBSS);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2CommsQualityANL:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig( hw, 
+				HFA384x_RID_COMMSQUALITY, bytebuf, 
+				HFA384x_RID_COMMSQUALITY_LEN);
+		*uint32 = hfa384x2host_16(((hfa384x_commsquality_t *)bytebuf)->ANL_currFC);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2CurrentTxRate:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CURRENTTXRATE, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2EDThreshold:
+case DIDmib_p2_p2Table_p2CDThreshold:
+case DIDmib_p2_p2Table_p2DeferThreshold:
+case DIDmib_p2_p2Table_p2CellSearchThreshold:
+case DIDmib_p2_p2Table_p2OORThreshold:
+	/*
+	 *  HFA384x_RID_CURRENTSCALETHRESH
+	 */
+
+/*----------------------------------------------------------------*/
+case DIDmib_p2_p2Table_p2CurrentPowerState:
+	if ( isget ) {
+		result = hfa384x_drvr_getconfig16( hw, 
+				HFA384x_RID_CURRENTPOWERSTATE, wordbuf);
+		prism2mgmt_prism2int2p80211int(wordbuf, uint32);
+	} else {
+		msg->resultcode.data =
+			P80211ENUM_resultcode_cant_set_readonly_mib;
+	}
+	break;
+
 /*----------------------------------------------------------------*/
 /* These items are not supported at this time */
 
@@ -1198,16 +1610,6 @@ case DIDmib_dot11smt_dot11AuthenticationAlgorithmsTable_dot11AuthenticationAlgor
 case DIDmib_dot11smt_dot11AuthenticationAlgorithmsTable_dot11AuthenticationAlgorithm6:
 case DIDmib_dot11smt_dot11AuthenticationAlgorithmsTable_dot11AuthenticationAlgorithmsEnable6:
 
-/* The following could be implemented by maintaining priv state variables. */
-/* They might be useful to look at on the AP when folks are debugging auth */
-/*  and assoc failures. */
-case DIDmib_dot11smt_dot11StationConfigTable_dot11DisassociateReason:
-case DIDmib_dot11smt_dot11StationConfigTable_dot11DisassociateStation:
-case DIDmib_dot11smt_dot11StationConfigTable_dot11DeauthenticateReason:
-case DIDmib_dot11smt_dot11StationConfigTable_dot11DeauthenticateStation:
-case DIDmib_dot11smt_dot11StationConfigTable_dot11AuthenticateFailStatus:
-case DIDmib_dot11smt_dot11StationConfigTable_dot11AuthenticateFailStation:
-
 /* WEP Key mappings aren't supported in the f/w */
 case DIDmib_dot11smt_dot11WEPKeyMappingsTable_dot11WEPKeyMappingIndex:
 case DIDmib_dot11smt_dot11WEPKeyMappingsTable_dot11WEPKeyMappingAddress:
@@ -1274,17 +1676,6 @@ case DIDmib_dot11phy_dot11AntennasListTable_dot11SupportedRxAntenna:
 case DIDmib_dot11phy_dot11AntennasListTable_dot11DiversitySelectionRx:
 
 /* TODO: Prism2 extension items.  Implement as needed. */
-case DIDmib_p2_p2Table_p2SystemScale:
-case DIDmib_p2_p2Table_p2MaxDataLen:
-case DIDmib_p2_p2Table_p2EnhancePowerSaveMode:
-case DIDmib_p2_p2Table_p2MulticastRx:
-case DIDmib_p2_p2Table_p2MaxSleepDuration:
-case DIDmib_p2_p2Table_p2PMHoldoverDuration:
-case DIDmib_p2_p2Table_p2OwnName:
-case DIDmib_p2_p2Table_p2McastPMBuffer:
-case DIDmib_p2_p2Table_p2TickTime:
-case DIDmib_p2_p2Table_p2MaxLoadTime:
-case DIDmib_p2_p2Table_p2DLBufferAddr:
 case DIDmib_p2_p2Table_p2PRIIdentity:
 case DIDmib_p2_p2Table_p2PRISUPRange:
 case DIDmib_p2_p2Table_p2PRI_CFI_ACTRange:
@@ -1297,22 +1688,10 @@ case DIDmib_p2_p2Table_p2STAIdentity:
 case DIDmib_p2_p2Table_p2StaSupRange:
 case DIDmib_p2_p2Table_p2STA_MFI_ActRange:
 case DIDmib_p2_p2Table_p2STA_CFI_ActRange:
-case DIDmib_p2_p2Table_p2PortStatus:
-case DIDmib_p2_p2Table_p2CommsQualityCQ:
-case DIDmib_p2_p2Table_p2CommsQualityASL:
-case DIDmib_p2_p2Table_p2CommsQualityANL:
-case DIDmib_p2_p2Table_p2CurrentTxRate:
-case DIDmib_p2_p2Table_p2EDThreshold:
-case DIDmib_p2_p2Table_p2CDThreshold:
-case DIDmib_p2_p2Table_p2DeferThreshold:
-case DIDmib_p2_p2Table_p2CellSearchThreshold:
-case DIDmib_p2_p2Table_p2OORThreshold:
-case DIDmib_p2_p2Table_p2CurrentPowerState:
 case DIDmib_p2_p2Table_p2IVPeriod:
 case DIDmib_p2_p2Table_p2HostDecrypt:
 case DIDmib_p2_p2Table_p2HostEncrypt:
 case DIDmib_p2_p2Table_p2MaxAssociations:
-case DIDmib_p2_p2Table_p2RoamingMode:
 case DIDmib_p2_p2Table_p2HostAuth:
 case DIDmib_p2_p2Table_p2CRCErrAll:
 case DIDmib_p2_p2Table_p2CRCErrMM:
@@ -1337,6 +1716,7 @@ default:
 					P80211ENUM_msgitem_status_data_ok;
 			}
 		} else {
+			WLAN_LOG_DEBUG1(1,"get/set failure, result=%d\n", result);
 			msg->resultcode.data =
 				P80211ENUM_resultcode_implementation_failure;
 		}
@@ -1649,7 +2029,7 @@ void prism2mgmt_get_grpaddr(UINT32 did, p80211pstrd_t *pstr,
 
 	if ( index >= 0 ) {
 		pstr->len = WLAN_ADDR_LEN;
-		memcpy(pstr->data, priv->grp_addr[index],
+		memcpy(pstr->data, priv->dot11_grp_addr[index],
 			WLAN_ADDR_LEN);
 	}
 
@@ -1688,10 +2068,10 @@ int prism2mgmt_set_grpaddr(UINT32 did, UINT8 *prism2buf,
 	trying to add more than the maximum allowed
 	number of group addresses in the list */
 	if ( memcmp(no_addr, pstr->data, WLAN_ADDR_LEN) != 0) {
-		if ( priv->grpcnt < MAX_GRP_ADDR ) {
-			memcpy( priv->grp_addr[priv->grpcnt],
+		if ( priv->dot11_grpcnt < MAX_GRP_ADDR ) {
+			memcpy( priv->dot11_grp_addr[priv->dot11_grpcnt],
 				pstr->data, WLAN_ADDR_LEN);
-			priv->grpcnt += 1;
+			priv->dot11_grpcnt += 1;
 		} else {
 			result = -1;
 		}
@@ -1699,25 +2079,25 @@ int prism2mgmt_set_grpaddr(UINT32 did, UINT8 *prism2buf,
 	/* here we're "deleting" an address from the
 	group address list.  Check to make sure we're
 	not trying to delete from an empty list */
-		if ( priv->grpcnt > 0 ) {
+		if ( priv->dot11_grpcnt > 0 ) {
 			index = prism2mgmt_get_grpaddr_index(did);
 
 			if ( index >= 0 ) {
 				/* check to make sure there is an address
 				to delete at the requested group address */
-				if ( memcmp(priv->grp_addr[index],
+				if ( memcmp(priv->dot11_grp_addr[index],
 					no_addr,
 					WLAN_ADDR_LEN) != 0) {
 
-					priv->grpcnt -= 1;
+					priv->dot11_grpcnt -= 1;
 					/* shift all the addresses following
 						the one to delete */
-					memcpy( priv->grp_addr[index],
-						priv->grp_addr[index + 1],
-						((priv->grpcnt)-index) * WLAN_ADDR_LEN);
+					memcpy( priv->dot11_grp_addr[index],
+						priv->dot11_grp_addr[index + 1],
+						((priv->dot11_grpcnt)-index) * WLAN_ADDR_LEN);
 					/* erase the last address that now appears
 					twice */
-					memcpy( priv->grp_addr[priv->grpcnt],
+					memcpy( priv->dot11_grp_addr[priv->dot11_grpcnt],
 						no_addr,
 						WLAN_ADDR_LEN);
 				}
